@@ -1,4 +1,4 @@
 from DKConnection import DKConnection
 
 conn = DKConnection("cloud.datakitchen.io", "armand+hm@datakitchen.io", "%Gun8D9M")
-results = conn.createOrder("hemonc_sftp_automation", 'hemonc_sftp_automation' ,'test-variation')
+results = conn.createOrder("hemonc_sftp_automation", 'hemonc_sftp_automation' ,'test-variation', retries=2)
